# MBASIC Curses UI Keyboard Shortcuts

## Editor

| Key | Action |
|-----|--------|
| `Ctrl+C` | Continue execution |
| `Ctrl+G` | Go to line |
| `Ctrl+H` | Open help browser |
| `Ctrl+N` | New program |
| `Ctrl+O` | Open/Load BASIC file |
| `Ctrl+Q` | Quit |
| `Ctrl+E` | Renumber all lines (RENUM) |
| `Ctrl+R` | Run program |
| `Ctrl+V` | Save program (Ctrl+S unavailable - terminal flow control) |
| `Ctrl+P` | Settings |
| `Ctrl+T` | Step statement (execute one statement) |
| `Ctrl+K` | Step Line (execute all statements on current line) |
| `Ctrl+X` | Stop program execution |
| `Ctrl+B` | Toggle breakpoint |
| `Ctrl+W` | Toggle variables window |

## Help Browser

| Key | Action |
|-----|--------|
| `U` | Navigate back |
| `Enter` | Follow link |
| `Tab` | Next link |
| `ESC` | Close help browser |
| `↓` | Scroll down |
| `↑` | Scroll up |
| `/` | Search help |

